@@ -105,6 +105,16 @@ impl<'a> Stream<'a> {
         Ok(self.curr_byte_unchecked())
     }
 
+    /// Returns a byte from a current stream position.
+    ///
+    /// # Panics
+    ///
+    /// - if the current position is after the end of the data
+    #[inline]
+    pub fn curr_byte_unchecked(&self) -> u8 {
+        self.bytes[self.pos]
+    }
+
     /// Checks that current byte is equal to provided.
     ///
     /// Returns `false` if no bytes left.
@@ -117,11 +127,6 @@ impl<'a> Stream<'a> {
         }
     }
 
-    #[inline]
-    fn curr_byte_unchecked(&self) -> u8 {
-        self.bytes[self.pos]
-    }
-
     /// Returns a byte from a current stream position if there is one.
     #[inline]
     pub fn get_curr_byte(&self) -> Option<u8> {
